@@ -5,6 +5,7 @@
    libraries.
 
    Copyright (C) 2014, The University of Texas at Austin
+   Copyright (C) 2018 - 2019, Advanced Micro Devices, Inc.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are
@@ -14,9 +15,9 @@
     - Redistributions in binary form must reproduce the above copyright
       notice, this list of conditions and the following disclaimer in the
       documentation and/or other materials provided with the distribution.
-    - Neither the name of The University of Texas at Austin nor the names
-      of its contributors may be used to endorse or promote products
-      derived from this software without specific prior written permission.
+    - Neither the name(s) of the copyright holder(s) nor the names of its
+      contributors may be used to endorse or promote products derived
+      from this software without specific prior written permission.
 
    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -65,7 +66,7 @@ void bli_gemm_int
 	{
         if ( bli_thread_am_ochief( thread ) )
 		    bli_scalm( beta, c );
-        bli_thread_obarrier( thread );
+        bli_thread_barrier( thread );
 		return;
 	}
 
@@ -79,7 +80,7 @@ void bli_gemm_int
 
         if ( bli_thread_am_ochief( thread ) )
 		    bli_scalm( beta, c );
-        bli_thread_obarrier( thread );
+        bli_thread_barrier( thread );
 		return;
 	}
 
@@ -114,7 +115,8 @@ void bli_gemm_int
 
 		if ( im != BLIS_NAT )
 		{
-			if ( im == BLIS_4M1B && f == bli_gemm_ker_var2 ) f = bli_gemm4mb_ker_var2;
+			if ( im == BLIS_4M1B )
+			if ( f == bli_gemm_ker_var2 ) f = bli_gemm4mb_ker_var2;
 		}
 	}
 
